/*
  Copyright (c) 2010 Werner Riese 

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
*/

#ifndef PLASMA_WALLPAPER_FLYMODE
#define PLASMA_WALLPAPER_FLYMODE
 
#include <QtGui>

#include <KUrlRequester>
 
#include <Plasma/Wallpaper>
 
 
class FlyMode : public Plasma::Wallpaper {
    
    Q_OBJECT
    
    static const int SPEED_MIN         = 6;
    static const int SPEED_MAX         = 96;
    static const int SPEED_DEFAULT     = 24;
    static const int FRAMES_PER_SECOND = 12;
    static const int SPEED_STEP        = 6;
    static const int SPEED_STEP_COUNT  = 16;

    
    public:
        	
        FlyMode(QObject* parent, const QVariantList& args);
        ~FlyMode();
 
        virtual void     paint(QPainter* painter, const QRectF& exposedRect);
        virtual void     save(KConfigGroup &config);
        virtual QWidget* createConfigurationInterface(QWidget* parent);
        

    signals:

        void settingsChanged(bool);

        
    protected:
        
        virtual void init(const KConfigGroup &config);

    
    protected slots:

        void setWallpaper(const QString& url);
        void updateWallpaper();
        void setWallpaper(const KUrl& url);
        void setSpeed(const int speed);
        void setDirection(const int index);

  
    private:
        
        int            _screenWidth;
        int            _screenHeight;
        QTimer*        _timer;
        float          _pictureOffset;   
        QPixmap*       _pixmap;
        QString        _wallpaper;
        int            _pixelPerSecond;
        bool           _directionVertical;
        QLabel*        _label1;
        KUrlRequester* _kurl;
        QComboBox*     _comboBox;
        QLabel*        _label2;
        QSlider*       _slider;
        bool           _stopPaint;
        bool           _pixmapLoaded;
};


K_EXPORT_PLASMA_WALLPAPER(FlyMode, FlyMode)
 
#endif